Skip to main content

Readit - Command Line Tool

Python Licence Build Status Documentation Status

Introduction

Readit is command line bookmark manager. It is a command line utility to add, delete, update and display the bookmarks. It is a powerful bookmark manager written in Python. It uses SQLite3 database to store the bookmarks.

Features

  • Bookmark multiple URLs at a time

  • Bookmark URL with respective Tags at the same time [NEW]

  • Search and display Bookmarks by TAG and URL’s substring

  • Display all Bookmarks in table format

  • Remove single or all Bookmarked URL

  • Update a Bookmarked URL with a specific ID

  • URL validation

  • Open multiple URLs in the browser

  • Choose specific folder and Export bookmarks into the CSV file [NEW]

  • Show all Tags available in the database

  • Bookmark URLs either online or offline

Dependencies

Features

Dependancy

Scripting Language

Python 3.0+

HTTP(S)

requests

Command-line parsing

click

Database

SQLite3

Display Bookmarks in Table

beautifultable

Installation

Readit is available on PyPI and can be installed with pip3:

pip3 install --user readit

Command line options

Usage: readit [OPTIONS] [INSERT]...

    Readit - Command-line bookmark manager tool.
Options:
-a, --add TEXT          Add urls --> readit -a <url1> <url2>
-t, --tag TEXT          Use to tag url --> readit -a <url1> -t <tag1>
-d, --delete TEXT       Remove a URL of particular ID --> readit -d <url_id>
-c, --clear TEXT        Clear bookmarks --> readit -c
-u, --update TEXT       Update a URL for specific ID --> readit -u
                        <existing_id> <new_url>
-s, --search TEXT       Search for bookmarks using either a tag or a
                        substring of the URL --> readit -s <tag> or
                        <substring>
-v, --view TEXT...      Show bookmarks --> readit -v
-o, --openurl TEXT      Open a URL in your browser by entering a part of the
                        URL. --> readit -o <url_substring>
-V, --version           Check latest version --> readit -V
-e, --export TEXT...    Export URLs in csv file --> readit -e
-tl, --taglist TEXT...  Show all Tags --> readit -tl
--help                  Show this message and exit.

Examples

  1. Bookmark multiple URLs:

$ readit <url1> <url2> ...
or
$ readit --add <url1> <url2> ...
or
$ readit -a <url1> <url2> ...
  1. Bookmark urls and tags at the same time

$ readit -a <url1> -t <tag1>
  1. View all available bookmarks:

$ readit -v
or
$ readit --view
  1. Update a bookmark using its ID:

$ readit -u <url_id> <url>
or
$ readit --update <url_id> <url>
  1. Delete a bookmarked URL using its ID:

$ readit -d <url_id>
or
$ readit --delete <url_id>
  1. Clear all the bookmarks:

$ readit -c
or
$ readit --clear
  1. Search and Display all bookmarks using the TAG or URL’s substring:

$ readit -s <tag_name> or <url_substring>
or
$ readit --search <tag_name> or <url_substring>
  1. Open URL in the Browser using URL’s substring:

$ readit -o <url_substring>
or
$ readit --openurl <url_substring>
  1. Export bookmarks into the CSV file:

$ readit --export
or
$ readit -e
  1. Show all Tags available in the database

$ readit -tl
or
$ readit --taglist

How to install source code for development

  • Clone project from github:

$ git clone https://github.com/pythonpune/readit.git
  • We recommend to create and activate a virtualenv first:

$ cd readit/

$ python3 -m venv env

$ source env/bin/activate

$ pip3 install setuptools
  • To install using setup.py file:

(env) $ python setup.py install
  • To make a build of the project:

(env) $ python setup.py build

Licence

Readit - Command line tool is licensed under GNU General Public License v3.0.

Metadata

Release files for readit 1.0.3

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for readit 1.0.3
File Size Uploaded
readit-1.0.3.tar.gz 66.1 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for readit 1.0.3
File Interpreter ABI Platform
readit-1.0.3-py3-none-any.whl Python 3 none any Details

Total release size: 90.3 kB

Release files / readit-1.0.3.tar.gz

Download URL readit-1.0.3.tar.gz
Size 66.1 kB
Tags Source
SHA-256 checksum
How to use checksums
59fc799474a04657135389163b868c01ffb0f8dea72c22541cf9144e20582d6b
BLAKE2b-256 checksum
How to use checksums
1d81178312000a7324317866cf9e1d3ac576ebbb75f79ebc7ca9d408d1d42102
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.1.1 CPython/3.12.7

Release files / readit-1.0.3-py3-none-any.whl

Download URL readit-1.0.3-py3-none-any.whl
Size 24.2 kB
Tags Python 3
SHA-256 checksum
How to use checksums
73e85da06f6c39ce1db9958edbb6bc5a2b18158f68e8b6f877ba55469fcb9b3e
BLAKE2b-256 checksum
How to use checksums
580f94079d76d415dda345b9db193a1f9be0993c76d625a992e89235e5b9e15f
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.1.1 CPython/3.12.7

Release history Release notifications | RSS feed

This release

1.0.3 This release

2 release files

0.3

2 release files

0.2

1 release file

0.1.1

1 release file

0.1

1 release file

0.0.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page